ipsec whack --impair suppress_retransmits
# expected to fail
ipsec auto --up westnet-eastnet-ikev2
echo done
